Name:           python-Traits
Version:        4.3.0
Release:        1%{?dist}
Summary:        Explicitly typed attributes for Python
Group:          Development/Libraries
# Images have different licenses. For image license breakdown check
# image_LICENSE.txt file. Except enthought/traits/ui/editors_gen.py
# which is GPLv2+ all remaining source or image files are in BSD
# 3-clause license. Confirmed from upstream.
License:        BSD and EPL and LGPLv2 and GPLv2+
URL:            http://code.enthought.com/projects/traits/
Source0:        http://www.enthought.com/repo/ets/traits-%{version}.tar.gz
BuildRequires:  python-setupdocs, python-setuptools, python2-devel
Requires:       numpy
Provides:       python-traits = %{version}-%{release}

# we don't want to provide private python extension libs in either the python2 or python3 dirs
%global __provides_exclude_from ^(%{python_sitearch}|%{python3_sitearch})/.*\\.so$

%description
The traits package developed by Enthought provides a special type
definition called a trait. Although they can be used as normal Python object 
attributes, traits also have several additional characteristics: 

* Initialization: A trait can be assigned a default value.
* Validation: A trait attribute's type can be explicitly declared.
* Delegation: The value of a trait attribute can be contained either
  in another object.
* Notification: Setting the value of a trait attribute can trigger
  notification of other parts of the program.
* Visualization: User interfaces that permit the interactive
  modification of a trait's value can be automatically constructed
  using the trait's definition.

%prep
%setup -q -n traits-%{version}

rm -rf *.egg-info

# file not utf-8
for f in image_LICENSE_Eclipse.txt docs/Pydoh_T3UMdoc_HOWTO.txt
do
  iconv -f iso8859-1 -t utf-8 ${f} > ${f}.conv && mv -f ${f}.conv ${f}
done

%build
CFLAGS="$RPM_OPT_FLAGS" python setup.py build

%install
python setup.py install -O1 --skip-build --root $RPM_BUILD_ROOT

rm $RPM_BUILD_ROOT%{python_sitearch}/traits/protocols/_speedups.c
rm $RPM_BUILD_ROOT%{python_sitearch}/traits/ctraits.c

%check
python setup.py test

%files
%doc *.txt docs/*.pdf examples
%doc docs/traitsdocreadme.txt docs/CHANGES.txt
%{python_sitearch}/*.egg-info
%{python_sitearch}/traits

%changelog
* Tue Apr 23 2013 Orion Poplawski <orion@cora.nwra.com> - 4.3.0-1
- Update to 4.3.0
- Add python lib provides filter
- Add Provides: python-traits
- Drop line-ending fix, no longer needed
- Add %%check
- Drop %%defattr

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Jun 6 2012 Orion Poplawski <orion@cora.nwra.com> - 4.2.0-1
- Update to 4.2.0

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.5.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Jan 05 2011 Rakesh Pandit <rakesh@fedoraproject.org> 3.5.0-1
- Updated to 3.5.0

* Fri Aug 13 2010 Chen Lei <supercyper@163.com> 3.4.0-1
- Update spec to match latest guidelines w.r.t %%clean
- Fix timestamps for example files
- Remove BR:numpy

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 3.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Sun Jan 31 2010 Rakesh Pandit <rakesh@fedoraproject.org> 3.2.0-1
- Updated to 3.2.0

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Jun 12 2009 Rakesh Pandit <rakesh@fedoraproject.org> 3.1.0-2
- Fixed missing setupdocs BR

* Fri Jun 12 2009 Rakesh Pandit <rakesh@fedoraproject.org> 3.1.0-1
- Updated

* Tue Jan 27 2009 Rakesh Pandit <rakesh@fedoraproject.org> 3.0.2-2
- Fixed permissions for ctraits.so and _speedups.so
- Fixed license after confirming from upstream

* Sun Dec 07 2008 Rakesh Pandit <rakesh@fedoraproject.org> 3.0.2-1
- Initial package
